:html_theme.sidebar_secondary.remove: true

.. This documentation is based on that of Pandas and SciPy, and uses the PyData theme

.. currentmodule:: bblean

***************************
BitBIRCH-Lean documentation
***************************

.. toctree::
   :hidden:

   installing
   user-guide
   API reference <api-reference>
   publications

**Date**: |today| **Version**: |version|

**Useful links**:
`GitHub Repo <https://github.com/mqcomplab/bblean>`_  |
`Issue Tracker <https://github.com/mqcomplab/bblean/issues>`_  |
`Miranda-Quintana Lab at GitHub <https://github.com/mqcomplab>`_

**BitBIRCH-Lean** is an open-source, high-throughput implementation of the BitBIRCH
clustering algorithm designed for clustering very large molecular libraries.
It is developed by the Miranda-Quintana Lab at the University of Florida.

The BitBIRCH-Lean documentation is a work in progress, expect many updates soon!

.. grid:: 1 1 2 2
    :gutter: 2 3 4 4

    .. grid-item-card::
        :img-top: _static/installing.svg
        :text-align: center

        **Installing**
        ^^^

        Want to install BitBIRCH-Lean? Read this section for details on how to install
        the library.

        +++

        .. button-ref:: installing
            :color: secondary
            :click-parent:

            To the installation guide

    .. grid-item-card::
        :img-top: _static/user-guide.svg
        :text-align: center

        **User guide**
        ^^^

        Start here! This sections describes how to use BitBIRCH-Lean and the ``bb`` CLI
        to cluster huge molecular libraries.

        +++

        .. button-ref:: user-guide
            :color: secondary
            :click-parent:

            To the user guide

    .. grid-item-card::
        :img-top: _static/api.svg
        :text-align: center

        **API reference**
        ^^^

        A detailed description of the BitBIRCH-Lean API. It shows all its *public*
        functions, classes, and their methods and properties. Use this for reference.

        +++

        .. button-ref:: api-reference
            :color: secondary
            :click-parent:

            To the API reference

    .. grid-item-card::
        :img-top: _static/publications.svg
        :text-align: center

        **Publications**
        ^^^

        Articles associated with the BitBIRCH algorithm. Please consult and cite the
        corresponding articles if you use find BitBIRCH useful for your work.

        +++

        .. button-ref:: publications
            :color: secondary
            :click-parent:

            To the publications page
